#
# spec file for package hyperscan
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _lto_cflags %{nil}
%define sover 5
Name:           hyperscan
Version:        5.2.1
Release:        lp152.1.3
Summary:        Regular expression matching library
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://www.hyperscan.io/
#Git-Clone:     https://github.com/intel/hyperscan.git
Source:         https://github.com/intel/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  boost-devel >= 1.57
BuildRequires:  cmake
BuildRequires:  gcc-c++ >= 4.9
BuildRequires:  libpcap-devel
BuildRequires:  pkgconfig
BuildRequires:  python
BuildRequires:  ragel
BuildRequires:  pkgconfig(libpcre)
BuildRequires:  pkgconfig(sqlite3)
ExclusiveArch:  %{ix86} x86_64

%description
Hyperscan is a multiple regex matching library. It
follows the regular expression syntax of the commonly-used libpcre
library, but is a standalone library with its own C API.

Hyperscan uses hybrid automata techniques to allow simultaneous
matching of large numbers (up to tens of thousands) of regular
expressions and for the matching of regular expressions across streams
of data.

Hyperscan is typically used in a DPI library stack.

%package -n libhs%{sover}
Summary:        Regular expression matching library
Group:          System/Libraries

%description -n libhs%{sover}
Hyperscan is a multiple regex matching library. It
follows the regular expression syntax of the commonly-used libpcre
library, but is a standalone library with its own C API.

Hyperscan uses hybrid automata techniques to allow simultaneous
matching of large numbers (up to tens of thousands) of regular
expressions and for the matching of regular expressions across streams
of data.

Hyperscan is typically used in a DPI library stack.

%package devel
Summary:        Libraries and header files for the hyperscan library
Group:          Development/Libraries/C and C++
Requires:       libhs%{sover} = %{version}

%description devel
Hyperscan is a multiple regex matching library. It
follows the regular expression syntax of the commonly-used libpcre
library, but is a standalone library with its own C API.

Hyperscan uses hybrid automata techniques to allow simultaneous
matching of large numbers (up to tens of thousands) of regular
expressions and for the matching of regular expressions across streams
of data.

Hyperscan is typically used in a DPI library stack.

This package provides the libraries, include files and other resources
needed for developing Hyperscan applications.

%prep
%setup -q

%build
%cmake \
  -DCMAKE_INSTALL_DOCDIR=%{_defaultdocdir}/%{name} \
  -DBUILD_AVX512=ON
make %{?_smp_mflags}

%install
%cmake_install

%post -n libhs%{sover} -p /sbin/ldconfig
%postun -n libhs%{sover} -p /sbin/ldconfig

%files -n libhs%{sover}
%license COPYING LICENSE
%{_libdir}/libhs.so.%{sover}*
%{_libdir}/libhs_runtime.so.%{sover}*

%files devel
%{_libdir}/libhs.so
%{_libdir}/libhs_runtime.so
%{_libdir}/pkgconfig/libhs.pc
%{_includedir}/hs/
%dir %{_defaultdocdir}/%{name}
%dir %{_defaultdocdir}/%{name}/examples
%doc %{_defaultdocdir}/%{name}/examples/README.md
%doc %{_defaultdocdir}/%{name}/examples/*.cc
%doc %{_defaultdocdir}/%{name}/examples/*.c

%changelog
* Wed Oct 30 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 5.2.1
  - Fix compile issue when `BUILD_SHARED_LIBS` is on in
    release mode.
- Update to version 5.2.0
  - Literal API: add new API `hs_compile_lit()` and
    `hs_compile_lit_multi()` to process pure literal rule sets.
    The 2 literal APIs treat each expression text in a literal
    sense without recognizing any regular grammers.
  - Logical combination: add support for purely negative
    combinations, which report match at EOD in case of no
    sub-expressions matched.
  - Fix uninitialized use of `scatter_unit_uX` due to padding.
  - Fix numerical result out of range error.
  - Avoid corruption of pending combination report in streaming mode.
  - Fix scratch free issue when memory allocation fails.
- Builds are broken with LTO - disable for for now
* Wed Apr 10 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 5.1.1
  * Add extra detection and handling when invalid rose programs are
    triggered.
  * Fix CMake parsing of CPU architecure for GCC-9.
  * Fix rose literal programs for multi-pattern matching when no
    pattern ids are provided.
  * Fix library install path in pkg-config files.
* Thu Jan 31 2019 mardnh@gmx.de
- Update to version 5.1.0
  * Improve DFA state compression by wide-state optimization to
    reduce bytecode size.
  * Create specific interpreter runtime handling to boost the
    performance of pure literal matching.
  * Optimize original presentation of interpreter (the "Rose"
    engine ) to increase overall performance.
  * Bugfix for logical combinations: fix error reporting
    combination's match in case of sub-expression has EOD match
    under streaming mode.
  * Bugfix for logical combinations: fix miss reporting
    combination's match under vacuous input.
  * Fix compile error with Boost 1.68.0.
  * avoid pcre error for hscollider with installed PCRE package.
  * Update version of PCRE used by testing tools as a syntax and
    semantic reference to PCRE 8.41 or above.
- Remove patch:
  * hyperscan-build.patch (fixed upstream)
* Tue Sep 25 2018 mardnh@gmx.de
- Add patch
  * hyperscan-build.patch (fix build for Tumbleweed)
* Tue Jul 10 2018 mardnh@gmx.de
- Update to version 5.0.0
  * Introduce chimera hybrid engine of Hyperscan and PCRE, to fully
    support PCRE syntax as well as to take advantage of the high
    performance nature of Hyperscan.
  * New API feature: logical combinations (AND, OR and NOT) of
    patterns in a given pattern set.
  * Windows porting: hsbench, hscheck, hscollider and hsdump tools
    now available on Windows 8 or newer.
  * Improve undirected graph implementation to avoid graph copy and
    reduce compile time.
  * Bugfix for issue #86: enable hscollider for installed PCRE
    package.
* Tue Jun  5 2018 jengelh@inai.de
- Ensure neutrality of descriptions.
* Mon Jun  4 2018 mardnh@gmx.de
- Moved inline changes to hyperscan.changes
- Specfile cleanup
* Mon May 28 2018 quicktrick@mail.ru
- Minor spec improvements
* Fri May 18 2018 quicktrick@mail.ru
- Boost 1.67.0 update
* Fri Apr 13 2018 quicktrick@mail.ru
- Adapted for openSUSE Tumbleweed
* Wed Feb  7 2018 releng@fedoraproject.org
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild
* Thu Jan 25 2018 jtfas90@gmail.com
- upstream bugfix release
* Fri Sep 22 2017 jtfas90@gmail.com
- latest upstream release
* Wed Aug  2 2017 releng@fedoraproject.org
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild
* Thu Jul 27 2017 jtfas90@gmail.com
- upstream bugfix release
* Wed Jul 26 2017 releng@fedoraproject.org
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild
* Fri Jun 16 2017 jtfas90@gmail.com
- upstream bugfix release
* Fri Jun  9 2017 jtfas90@gmail.com
- Update to latest upstream
- Removed CMakeLists.txt patch, moved into upstream
* Fri May 12 2017 jtfas90@gmail.com
- Update to latest upstream
- Add CMakeLists.txt path patch
- Spec file updates to meet packaging standards
* Fri Sep  2 2016 jtfas90@gmail.com
- Updated to latest upstream release.
* Fri Jul  1 2016 ish@unx.ca
- Initial package of Hyperscan.
